@@ -16,18 +16,19 @@ class UserInfo(object):
 
         return cls(json_data['user_id'], json_data['authorities'])
 
-    def __init__(self, user_id, authorities):
+    def __init__(self, principal_id, authorities, **extra_context):
         if isinstance(authorities, string_types):
             authorities = authorities.split(',')
         elif not isinstance(authorities, (list, tuple)):
             raise ValueError('Authorites must be comma-seperated, or a list')
 
-        self.user_id = user_id
+        self.principal_id = principal_id
         self.authorities = authorities
+        self.extra_context = extra_context
 
-    def to_dict(self):
+    def as_context(self):
         '''Return the authorizer context as a dict'''
         return dict(
-            user_id=self.user_id,
-            authorities=','.join(self.authorities)
+            authorities=','.join(self.authorities),
+            **self.extra_context
         )
